==> camel-k-model-v1-6.0.0-sources.jar: io/fabric8/camelk/v1/IntegrationPlatformBuildSpecFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IntegrationPlatformBuildSpecFluent<A extends IntegrationPlatformBuildSpecFluent<A>> extends Fluent<A>{
  public String getBaseImage();
  public A withBaseImage(String baseImage);
  public Boolean hasBaseImage();
  public String getBuildStrategy();
  public A withBuildStrategy(String buildStrategy);
  public Boolean hasBuildStrategy();
  public Boolean getKanikoBuildCache();
  public A withKanikoBuildCache(Boolean kanikoBuildCache);
  public Boolean hasKanikoBuildCache();
  
  /**
   * This method has been deprecated, please use method buildMaven instead.
   * @return The buildable object.
   */
  @Deprecated
  public MavenSpec getMaven();
  public MavenSpec buildMaven();
  public A withMaven(MavenSpec maven);
  public Boolean hasMaven();
  public IntegrationPlatformBuildSpecFluent.MavenNested<A> withNewMaven();
  public IntegrationPlatformBuildSpecFluent.MavenNested<A> withNewMavenLike(MavenSpec item);
  public IntegrationPlatformBuildSpecFluent.MavenNested<A> editMaven();
  public IntegrationPlatformBuildSpecFluent.MavenNested<A> editOrNewMaven();
  public IntegrationPlatformBuildSpecFluent.MavenNested<A> editOrNewMavenLike(MavenSpec item);
  public String getPersistentVolumeClaim();
  public A withPersistentVolumeClaim(String persistentVolumeClaim);
  public Boolean hasPersistentVolumeClaim();
  public String getPublishStrategy();
  public A withPublishStrategy(String publishStrategy);
  public Boolean hasPublishStrategy();
  
  /**
   * This method has been deprecated, please use method buildRegistry instead.
   * @return The buildable object.
   */
  @Deprecated
  public RegistrySpec getRegistry();
  public RegistrySpec buildRegistry();
  public A withRegistry(RegistrySpec registry);
  public Boolean hasRegistry();
  public A withNewRegistry(String address,String ca,Boolean insecure,String organization,String secret);
  public IntegrationPlatformBuildSpecFluent.RegistryNested<A> withNewRegistry();
  public IntegrationPlatformBuildSpecFluent.RegistryNested<A> withNewRegistryLike(RegistrySpec item);
  public IntegrationPlatformBuildSpecFluent.RegistryNested<A> editRegistry();
  public IntegrationPlatformBuildSpecFluent.RegistryNested<A> editOrNewRegistry();
  public IntegrationPlatformBuildSpecFluent.RegistryNested<A> editOrNewRegistryLike(RegistrySpec item);
  public String getRuntimeProvider();
  public A withRuntimeProvider(String runtimeProvider);
  public Boolean hasRuntimeProvider();
  public String getRuntimeVersion();
  public A withRuntimeVersion(String runtimeVersion);
  public Boolean hasRuntimeVersion();
  public Duration getTimeout();
  public A withTimeout(Duration timeout);
  public Boolean hasTimeout();
  public A withKanikoBuildCache();
  public interface MavenNested<N> extends Nested<N>,MavenSpecFluent<IntegrationPlatformBuildSpecFluent.MavenNested<N>>{
    public N and();
    public N endMaven();
    
  }
  public interface RegistryNested<N> extends Nested<N>,RegistrySpecFluent<IntegrationPlatformBuildSpecFluent.RegistryNested<N>>{
    public N and();
    public N endRegistry();
    
  }
  
}

==> camel-k-model-v1-6.1.0-sources.jar: io/fabric8/camelk/v1/IntegrationPlatformBuildSpecFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IntegrationPlatformBuildSpecFluent<A extends IntegrationPlatformBuildSpecFluent<A>> extends Fluent<A>{
  public A addToPublishStrategyOptions(String key,String value);
  public A addToPublishStrategyOptions(Map<String,String> map);
  public A removeFromPublishStrategyOptions(String key);
  public A removeFromPublishStrategyOptions(Map<String,String> map);
  public Map<String,String> getPublishStrategyOptions();
  public <K,V>A withPublishStrategyOptions(Map<String,String> publishStrategyOptions);
  public Boolean hasPublishStrategyOptions();
  public String getBaseImage();
  public A withBaseImage(String baseImage);
  public Boolean hasBaseImage();
  public String getBuildStrategy();
  public A withBuildStrategy(String buildStrategy);
  public Boolean hasBuildStrategy();
  public Boolean getKanikoBuildCache();
  public A withKanikoBuildCache(Boolean kanikoBuildCache);
  public Boolean hasKanikoBuildCache();
  
  /**
   * This method has been deprecated, please use method buildMaven instead.
   * @return The buildable object.
   */
  @Deprecated
  public MavenSpec getMaven();
  public MavenSpec buildMaven();
  public A withMaven(MavenSpec maven);
  public Boolean hasMaven();
  public IntegrationPlatformBuildSpecFluent.MavenNested<A> withNewMaven();
  public IntegrationPlatformBuildSpecFluent.MavenNested<A> withNewMavenLike(MavenSpec item);
  public IntegrationPlatformBuildSpecFluent.MavenNested<A> editMaven();
  public IntegrationPlatformBuildSpecFluent.MavenNested<A> editOrNewMaven();
  public IntegrationPlatformBuildSpecFluent.MavenNested<A> editOrNewMavenLike(MavenSpec item);
  public String getPersistentVolumeClaim();
  public A withPersistentVolumeClaim(String persistentVolumeClaim);
  public Boolean hasPersistentVolumeClaim();
  public String getPublishStrategy();
  public A withPublishStrategy(String publishStrategy);
  public Boolean hasPublishStrategy();
  
  /**
   * This method has been deprecated, please use method buildRegistry instead.
   * @return The buildable object.
   */
  @Deprecated
  public RegistrySpec getRegistry();
  public RegistrySpec buildRegistry();
  public A withRegistry(RegistrySpec registry);
  public Boolean hasRegistry();
  public A withNewRegistry(String address,String ca,Boolean insecure,String organization,String secret);
  public IntegrationPlatformBuildSpecFluent.RegistryNested<A> withNewRegistry();
  public IntegrationPlatformBuildSpecFluent.RegistryNested<A> withNewRegistryLike(RegistrySpec item);
  public IntegrationPlatformBuildSpecFluent.RegistryNested<A> editRegistry();
  public IntegrationPlatformBuildSpecFluent.RegistryNested<A> editOrNewRegistry();
  public IntegrationPlatformBuildSpecFluent.RegistryNested<A> editOrNewRegistryLike(RegistrySpec item);
  public String getRuntimeProvider();
  public A withRuntimeProvider(String runtimeProvider);
  public Boolean hasRuntimeProvider();
  public String getRuntimeVersion();
  public A withRuntimeVersion(String runtimeVersion);
  public Boolean hasRuntimeVersion();
  public Duration getTimeout();
  public A withTimeout(Duration timeout);
  public Boolean hasTimeout();
  public A withKanikoBuildCache();
  public interface MavenNested<N> extends Nested<N>,MavenSpecFluent<IntegrationPlatformBuildSpecFluent.MavenNested<N>>{
    public N and();
    public N endMaven();
    
  }
  public interface RegistryNested<N> extends Nested<N>,RegistrySpecFluent<IntegrationPlatformBuildSpecFluent.RegistryNested<N>>{
    public N and();
    public N endRegistry();
    
  }
  
}
